#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
/****************************************************************************
** Meta object code from reading C++ file 'file-editor-tab.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.1-1.i686/src/octave-4.0.1/libgui/src/m-editor/file-editor-tab.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'file-editor-tab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_file_editor_tab[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      74,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: signature, parameters, type, tag, flags
      34,   17,   16,   16, 0x05,
      99,   69,   16,   16, 0x05,
     131,   16,   16,   16, 0x05,
     154,  152,   16,   16, 0x05,
     203,  193,   16,   16, 0x05,
     256,  225,   16,   16, 0x05,
     302,  297,   16,   16, 0x05,
     329,   16,   16,   16, 0x05,
     368,   16,   16,   16, 0x05,

 // slots: signature, parameters, type, tag, flags
     404,  395,   16,   16, 0x0a,
     441,  430,   16,   16, 0x0a,
     487,  469,   16,   16, 0x0a,
     554,  540,   16,   16, 0x0a,
     602,  593,   16,   16, 0x2a,
     639,  636,   16,   16, 0x0a,
     675,  636,   16,   16, 0x0a,
     707,  636,   16,   16, 0x0a,
     737,  733,   16,   16, 0x0a,
     772,  768,   16,   16, 0x0a,
     806,  636,   16,   16, 0x0a,
     835,   16,   16,   16, 0x0a,
     857,  636,   16,   16, 0x0a,
     913,  883,   16,   16, 0x0a,
     952,  636,   16,   16, 0x0a,
     981,  636,   16,   16, 0x0a,
    1008,  636,   16,   16, 0x0a,
    1033,  636,   16,   16, 0x0a,
    1061,  636,   16,   16, 0x0a,
    1093,  636,   16,   16, 0x0a,
    1123,  636,   16,   16, 0x0a,
    1157,  636,   16,   16, 0x0a,
    1189,  636,   16,   16, 0x0a,
    1223,  636,   16,   16, 0x0a,
    1255,  636,   16,   16, 0x0a,
    1291,  636,   16,   16, 0x0a,
    1330,  152,   16,   16, 0x0a,
    1369,  636,   16,   16, 0x0a,
    1407,  636,   16,   16, 0x0a,
    1447,  636,   16,   16, 0x0a,
    1484,  636,   16,   16, 0x0a,
    1523,  768,   16,   16, 0x0a,
    1574,  636,   16,   16, 0x0a,
    1598,  636,   16,   16, 0x0a,
    1623,  636,   16,   16, 0x0a,
    1651,  636,   16,   16, 0x0a,
    1680, 1672,   16,   16, 0x0a,
    1710,  636,   16,   16, 0x2a,
    1746, 1736,   16,   16, 0x0a,
    1784,  636,   16,   16, 0x0a,
    1821, 1672,   16,   16, 0x0a,
    1865,  636,   16,   16, 0x2a,
    1905, 1672,   16,   16, 0x0a,
    1949,  636,   16,   16, 0x2a,
    2004, 1989,   16,   16, 0x0a,
    2060, 2050,   16,   16, 0x2a,
    2102,  395,   16,   16, 0x0a,
    2121,   16,   16,   16, 0x2a,
    2153, 2144, 2136,   16, 0x0a,
    2181, 2172,   16,   16, 0x0a,
    2199,   16,   16,   16, 0x2a,
    2210, 2144,   16,   16, 0x0a,
    2236,   16,   16,   16, 0x0a,
    2279, 2270,   16,   16, 0x08,
    2310, 2270,   16,   16, 0x08,
    2341, 2270,   16,   16, 0x08,
    2374, 2270,   16,   16, 0x08,
    2407, 2144,   16,   16, 0x08,
    2443, 2144,   16,   16, 0x08,
    2485,   16,   16,   16, 0x08,
    2528, 2521,   16,   16, 0x08,
    2574, 2568,   16,   16, 0x08,
    2610,   16,   16,   16, 0x08,
    2627,   16,   16,   16, 0x08,
    2656, 2647,   16,   16, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_file_editor_tab[] = {
    "file_editor_tab\0\0fileName,toolTip\0"
    "file_name_changed(QString,QString)\0"
    "copy_available,is_octave_file\0"
    "editor_state_changed(bool,bool)\0"
    "tab_remove_request()\0,\0"
    "add_filename_to_list(QString,QWidget*)\0"
    "file_name\0mru_add_file(QString)\0"
    "saveFileName,remove_on_success\0"
    "editor_check_conflict_save(QString,bool)\0"
    "info\0run_file_signal(QFileInfo)\0"
    "set_global_edit_shortcuts_signal(bool)\0"
    "request_open_file(QString)\0modified\0"
    "update_window_title(bool)\0enableCopy\0"
    "handle_copy_available(bool)\0"
    "line,margin,state\0"
    "handle_margin_clicked(int,int,Qt::KeyboardModifiers)\0"
    "settings,init\0notice_settings(const QSettings*,bool)\0"
    "settings\0notice_settings(const QSettings*)\0"
    "ID\0change_editor_state(const QWidget*)\0"
    "file_name_query(const QWidget*)\0"
    "set_focus(const QWidget*)\0dir\0"
    "set_current_directory(QString)\0ID,\0"
    "context_help(const QWidget*,bool)\0"
    "context_edit(const QWidget*)\0"
    "check_modified_file()\0save_file(const QWidget*)\0"
    "ID,fileName,remove_on_success\0"
    "save_file(const QWidget*,QString,bool)\0"
    "save_file_as(const QWidget*)\0"
    "print_file(const QWidget*)\0"
    "run_file(const QWidget*)\0"
    "context_run(const QWidget*)\0"
    "toggle_bookmark(const QWidget*)\0"
    "next_bookmark(const QWidget*)\0"
    "previous_bookmark(const QWidget*)\0"
    "remove_bookmark(const QWidget*)\0"
    "toggle_breakpoint(const QWidget*)\0"
    "next_breakpoint(const QWidget*)\0"
    "previous_breakpoint(const QWidget*)\0"
    "remove_all_breakpoints(const QWidget*)\0"
    "scintilla_command(const QWidget*,uint)\0"
    "comment_selected_text(const QWidget*)\0"
    "uncomment_selected_text(const QWidget*)\0"
    "indent_selected_text(const QWidget*)\0"
    "unindent_selected_text(const QWidget*)\0"
    "convert_eol(const QWidget*,QsciScintilla::EolMode)\0"
    "zoom_in(const QWidget*)\0"
    "zoom_out(const QWidget*)\0"
    "zoom_normal(const QWidget*)\0"
    "find(const QWidget*)\0ID,line\0"
    "goto_line(const QWidget*,int)\0"
    "goto_line(const QWidget*)\0ID,select\0"
    "move_match_brace(const QWidget*,bool)\0"
    "show_auto_completion(const QWidget*)\0"
    "insert_debugger_pointer(const QWidget*,int)\0"
    "insert_debugger_pointer(const QWidget*)\0"
    "delete_debugger_pointer(const QWidget*,int)\0"
    "delete_debugger_pointer(const QWidget*)\0"
    "insert,ID,line\0"
    "do_breakpoint_marker(bool,const QWidget*,int)\0"
    "insert,ID\0do_breakpoint_marker(bool,const QWidget*)\0"
    "set_modified(bool)\0set_modified()\0"
    "QString\0fileName\0load_file(QString)\0"
    "commands\0new_file(QString)\0new_file()\0"
    "file_has_changed(QString)\0"
    "handle_context_menu_edit(QString)\0"
    "decision\0handle_file_reload_answer(int)\0"
    "handle_file_resave_answer(int)\0"
    "handle_file_modified_answer(int)\0"
    "handle_find_dialog_finished(int)\0"
    "handle_save_file_as_answer(QString)\0"
    "handle_save_file_as_answer_close(QString)\0"
    "handle_save_file_as_answer_cancel()\0"
    "filter\0handle_save_as_filter_selected(QString)\0"
    "index\0handle_combo_eol_current_index(int)\0"
    "save_apis_info()\0auto_margin_width()\0"
    "line,col\0handle_cursor_moved(int,int)\0"
};

void file_editor_tab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        file_editor_tab *_t = static_cast<file_editor_tab *>(_o);
        switch (_id) {
        case 0: _t->file_name_changed((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->editor_state_changed((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 2: _t->tab_remove_request(); break;
        case 3: _t->add_filename_to_list((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 4: _t->mru_add_file((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->editor_check_conflict_save((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 6: _t->run_file_signal((*reinterpret_cast< const QFileInfo(*)>(_a[1]))); break;
        case 7: _t->set_global_edit_shortcuts_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->request_open_file((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->update_window_title((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->handle_copy_available((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->handle_margin_clicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[3]))); break;
        case 12: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 13: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
        case 14: _t->change_editor_state((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 15: _t->file_name_query((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 16: _t->set_focus((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 17: _t->set_current_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->context_help((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 19: _t->context_edit((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 20: _t->check_modified_file(); break;
        case 21: _t->save_file((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 22: _t->save_file((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 23: _t->save_file_as((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 24: _t->print_file((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 25: _t->run_file((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 26: _t->context_run((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 27: _t->toggle_bookmark((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 28: _t->next_bookmark((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 29: _t->previous_bookmark((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 30: _t->remove_bookmark((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 31: _t->toggle_breakpoint((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 32: _t->next_breakpoint((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 33: _t->previous_breakpoint((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 34: _t->remove_all_breakpoints((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 35: _t->scintilla_command((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 36: _t->comment_selected_text((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 37: _t->uncomment_selected_text((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 38: _t->indent_selected_text((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 39: _t->unindent_selected_text((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 40: _t->convert_eol((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< QsciScintilla::EolMode(*)>(_a[2]))); break;
        case 41: _t->zoom_in((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 42: _t->zoom_out((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 43: _t->zoom_normal((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 44: _t->find((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 45: _t->goto_line((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 46: _t->goto_line((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 47: _t->move_match_brace((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 48: _t->show_auto_completion((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 49: _t->insert_debugger_pointer((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 50: _t->insert_debugger_pointer((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 51: _t->delete_debugger_pointer((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 52: _t->delete_debugger_pointer((*reinterpret_cast< const QWidget*(*)>(_a[1]))); break;
        case 53: _t->do_breakpoint_marker((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QWidget*(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 54: _t->do_breakpoint_marker((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QWidget*(*)>(_a[2]))); break;
        case 55: _t->set_modified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 56: _t->set_modified(); break;
        case 57: { QString _r = _t->load_file((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 58: _t->new_file((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 59: _t->new_file(); break;
        case 60: _t->file_has_changed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 61: _t->handle_context_menu_edit((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 62: _t->handle_file_reload_answer((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 63: _t->handle_file_resave_answer((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 64: _t->handle_file_modified_answer((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 65: _t->handle_find_dialog_finished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 66: _t->handle_save_file_as_answer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 67: _t->handle_save_file_as_answer_close((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 68: _t->handle_save_file_as_answer_cancel(); break;
        case 69: _t->handle_save_as_filter_selected((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 70: _t->handle_combo_eol_current_index((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 71: _t->save_apis_info(); break;
        case 72: _t->auto_margin_width(); break;
        case 73: _t->handle_cursor_moved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData file_editor_tab::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject file_editor_tab::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_file_editor_tab,
      qt_meta_data_file_editor_tab, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &file_editor_tab::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *file_editor_tab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *file_editor_tab::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_file_editor_tab))
        return static_cast<void*>(const_cast< file_editor_tab*>(this));
    return QWidget::qt_metacast(_clname);
}

int file_editor_tab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 74)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 74;
    }
    return _id;
}

// SIGNAL 0
void file_editor_tab::file_name_changed(const QString & _t1, const QString & _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void file_editor_tab::editor_state_changed(bool _t1, bool _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void file_editor_tab::tab_remove_request()
{
    QMetaObject::activate(this, &staticMetaObject, 2, 0);
}

// SIGNAL 3
void file_editor_tab::add_filename_to_list(const QString & _t1, QWidget * _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void file_editor_tab::mru_add_file(const QString & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void file_editor_tab::editor_check_conflict_save(const QString & _t1, bool _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void file_editor_tab::run_file_signal(const QFileInfo & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void file_editor_tab::set_global_edit_shortcuts_signal(bool _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void file_editor_tab::request_open_file(const QString & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_END_MOC_NAMESPACE
